"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rule_1 = require("./rule");
const utils_1 = require("../utils");
class Fact {
    constructor(fact) {
        this.type = "Fact";
        utils_1.assert(!(!!fact.rule && !!fact.rules), "Cannot specify both rule and rules attribute", "FACT-100");
        utils_1.assert((!!fact.rules && !!fact.path) || !fact.rules, "If rules are multiple, specify a fact's path", "FACT-200");
        this.path = fact.path || (fact.name ? fact.name.replace(/([A-Z])/g, '.$1').trim() : (fact.rule ? fact.rule.name.split(".").join("") : undefined));
        this.name = fact.name || (this.path ? this.path.split(".").join("") : (fact.rule ? fact.rule.name : undefined));
        if (fact.rule) {
            this.rule = new rule_1.Rule(fact.rule);
            this.expectedFacts = this.rule.expectedFacts(fact.pathMapping || []);
        }
        else if (fact.rules) {
            fact.dataType = "array";
            this.rules = fact.rules.map(rule => new rule_1.Rule(rule));
            this.expectedFacts = [];
            this.rules.forEach(rule => {
                rule.expectedFacts(fact.pathMapping || []).forEach(fact => this.expectedFacts.push(fact));
            });
        }
        else {
            this.expectedFacts = [];
        }
        this.pathMapping = fact.pathMapping || [];
        this.dataType = fact.dataType || "string";
        this.sampleValue = { "bigint": "100", "string": "SampleString", "number": 7, "boolean": false, "date": Date.now(), "array": [], "object": {} }[this.dataType];
        if ((fact.sampleValue !== void 0) && (fact.dataType !== this.dataType)) {
            this.dataType = utils_1.guessTypeOf(fact.sampleValue);
        }
        this.enumerations = fact.enumerations;
        this.documentation = fact.documentation;
    }
    getPath(name) {
        const pathMap = this.pathMapping.find(map => map.replaceName === name);
        return ((pathMap && pathMap.withPath) || name);
    }
}
exports.default = Fact;
//# sourceMappingURL=fact.js.map