"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
class Rule {
    constructor(ruleInterface) {
        this.type = "Rule";
        this.id = ruleInterface.id;
        this.name = ruleInterface.name;
        this.title = ruleInterface.title;
        this.description = ruleInterface.description;
        this.statedAs = ruleInterface.statedAs;
        this.aliases = ruleInterface.aliases;
        this.dataType = ruleInterface.dataType || "string";
        this.sampleValue = ruleInterface.sampleValue;
        this.behaviour = ruleInterface.behaviour || "OnlyOnceWithAllFacts";
        this.documentation = ruleInterface.documentation || "";
    }
    expectedFacts(pathMapping = []) {
        if (this.statedAs !== undefined) {
            const vars = utils_1.extractUndeclaredVarsFromCode(this.statedAs).map(variable => {
                const fact2 = pathMapping.find((f) => { return f.replaceName === variable; });
                return fact2 && fact2.withPath || variable;
            });
            return vars;
        }
        return [];
    }
    getRule() {
        utils_1.assert(!!this.statedAs, `This rule hasn't been stated`, `FACT-01`);
        let code = this.statedAs || "";
        if ((code.indexOf("theResultIs") === -1)) {
            utils_1.assert(code.trim().split(";").length <= 1, `When using multiple statements, please use theResultIs.`, `FACT-02`);
            return utils_1.formatCode(`theResultIs(${code})`);
        }
        else {
            return utils_1.formatCode(code);
        }
    }
}
exports.Rule = Rule;
//# sourceMappingURL=rule.js.map